//
// $Id: test-lib.c,v 1.2 2001/08/28 00:50:29 mavetju Exp $
//
// test-lib.c - Part of ngrep-lib by Edwin Groothuis <edwin@mavetju.org>
//

#include <stdio.h>
#include <pcap.h>

#include <sys/types.h>
#include <sys/socket.h>

#include <netinet/in.h>
#include <netinet/in_systm.h>
#include <netinet/ip.h>
#include <netinet/tcp.h>
#include <netinet/udp.h>
#include <netinet/ip_icmp.h>

#include <arpa/inet.h>

#include "ngrep-lib.h"

void my_ip(struct ip *iphdr);
void my_tcp(struct ip *iphdr, struct tcphdr *tcphdr,char *data,int len);
void my_udp(struct ip *iphdr, struct udphdr *udphdr,char *data,int len);
void my_icmp(struct ip *iphdr, struct icmp *icmphdr,char *data,int len);
void my_info(char *interface,char *filter,char *match,char *output);
void my_stats(long received,long dropped);

int main(int argc,char **argv) {
    ngrep_callback_process(&my_ip,&my_tcp,&my_udp,&my_icmp);
    ngrep_callback_info(&my_info,&my_stats);
//  ngrep_main("port 53 or port 4000 or icmp","''","-d tun0");
    ngrep_setfilter("port 53 or port 4000 or icmp",NULL,"-d tun0");
    ngrep_run();
    return 0;
}

void my_info(char *interface,char *filter,char *match,char *output) {
    printf("interface: %s\nfilter: %s\nmatch: %s\noutput: %s\n",
	interface,filter,match,output);
}

void my_stats(long received, long dropped) {
    printf("received %ld packets, dropped %ld packets\n",
	received,dropped);
}

void my_ip(struct ip *iphdr) {
    printf("IP: from %s to %s\n",
	inet_ntoa(iphdr->ip_src),
	inet_ntoa(iphdr->ip_dst));
}

void my_tcp(struct ip *iphdr, struct tcphdr *tcp,char *data,int len) {
    printf("TCP: %d bytes from %s:%d to %s:%d\n",
	len,
	inet_ntoa(iphdr->ip_src),
	ntohs(tcp->th_sport),
	inet_ntoa(iphdr->ip_dst),
	ntohs(tcp->th_dport));
}
void my_udp(struct ip *iphdr, struct udphdr *udp,char *data,int len) {
    printf("UDP: %d bytes from %s:%d to %s:%d\n",
	len,
	inet_ntoa(iphdr->ip_src),
	ntohs(udp->uh_sport),
	inet_ntoa(iphdr->ip_dst),
	ntohs(udp->uh_dport));

}
void my_icmp(struct ip *iphdr, struct icmp *ic,char *data,int len) {
    printf("ICMP: %d bytes of type %d\n",len,ic->icmp_type);
}

